/* 用户管理
 * @Author: Li Hanlin
 * @Date: 2022-11-09 14:44:44
 * @Last Modified by: Li Hanlin
 * @Last Modified time: 2022-11-24 15:02:31
 */

import * as React from 'react';
import { useState, useMemo, useRef, useCallback } from 'react';
import DrawerPro from '@/components/DrawerPro';
import AutoTable from '@/components/AutoTable';
import PremButton from '@/components/PremButton';
import InitForm from '@/components/InitForm';
import getcolumns from './columns';
import { doFetch } from '@/utils/doFetch';
import { message, AutoComplete } from 'antd';

function User(props) {
  const actionRef = useRef(),
    formRef = useRef();
  const [drawer, setDrawer] = useState({
    visible: false,
  });

  const urlParams = {
    save: '/auth/sysUser/save',
    remove: '/auth/sysUser/deleteById',
    list: '/auth/sysUser/queryList',
    detail: '/auth/sysUser/detail',
  };

  const detail = (text, row, _, action) => {
    return (
      <PremButton
        btn={{
          size: 'small',
          type: 'link',
          onClick: () => {
            setDrawer((s) => ({
              ...s,
              visible: true,
              item: row,
              title: '详情',
              val: 'detail',
              title: row.userName + '的详细信息',
            }));
          },
        }}
      >
        详情
      </PremButton>
    );
  };

  const edit = (text, row, _, action) => {
    return (
      <PremButton
        btn={{
          size: 'small',
          onClick: () => {
            setDrawer((s) => ({
              ...s,
              visible: true,
              // item: row,
              detailpath: urlParams.detail,
              params: { id: row.id },
              title: '编辑',
              val: 'edit',
              onFinish: async (vals) => {
                console.log(1);
                let params = {
                  ...vals,
                  id: row.id,
                };
                let res = await doFetch({
                  url: urlParams.save,
                  params,
                });
                if (res.code === '0000') {
                  message.success('编辑成功！');
                  setDrawer((s) => ({
                    ...s,
                    visible: false,
                  }));
                  actionRef.current.reload();
                }
              },
            }));
          },
        }}
      >
        编辑
      </PremButton>
    );
  };

  const remove = (text, row, _, action) => {
    return (
      <PremButton
        pop={{
          title: '是否删除该用户?',
          okText: '确认',
          cancelText: '取消',
          onConfirm: async () => {
            let res = await doFetch({ url: urlParams.remove, params: { id: row.id } });
            if (res.code === '0000') {
              message.success('删除成功！');
              setDrawer((s) => ({
                ...s,
                visible: false,
              }));
              actionRef.current.reload();
            }
          },
        }}
        btn={{
          size: 'small',
          type: 'danger',
        }}
      >
        删除
      </PremButton>
    );
  };

  // const Adduser = () => {
  //   const [value, setValue] = useState('');
  //   const [options, setOptions] = useState([]);
  //   const debounce = lodash.debounce;
  //   const serchHandle = useCallback(
  //     debounce(async (val) => {
  //       console.log(val + '!!');
  //       if (val) {
  //         let res = await doFetch({
  //           url: '/auth/sysUser/queryLikeIotUsername',
  //           params: { username: val },
  //         });
  //         console.log(res);
  //       }
  //     }, 800),
  //     [],
  //   );
  //   const onSearch = (val) => {
  //     serchHandle(val);
  //   };
  //   const onSelect = (data) => {
  //     console.log('onSelect', data);
  //   };
  //   const onChange = (data) => {
  //     setValue(data);
  //   };
  //   return (
  //     <>
  //       <div style={{ marginBottom: 22 }}>
  //         <div style={{ marginBottom: 8 }}>用户名</div>
  //         <AutoComplete
  //           options={options}
  //           style={{
  //             width: '50%',
  //           }}
  //           onSelect={onSelect}
  //           onSearch={onSearch}
  //           placeholder="请输入用户名"
  //         />
  //       </div>
  //       <InitForm
  //         fields={columns}
  //         onFinish={() => {
  //           console.log(1);
  //         }}
  //       />
  //     </>
  //   );
  // };

  const columns = useMemo(() => {
    let defcolumn = getcolumns(setDrawer);
    return defcolumn.concat({
      title: '操作',
      valueType: 'option',
      width: 150,
      render: (text, row, _, action) => [edit(text, row, _, action), remove(text, row, _, action)],
    });
  }, []);

  return (
    <div style={{ position: 'relative' }}>
      <AutoTable
        pagetitle={<h3 className="page-title">用户管理</h3>}
        columns={columns}
        path={urlParams.list}
        actionRef={actionRef}
        pageextra={'add'}
        resizeable={false}
        addconfig={{
          // access: 'sysDepartment_save',
          btn: {
            type: 'primary',
            disabled: false,
            onClick: () => {
              setDrawer((s) => ({
                ...s,
                visible: true,
                item: {
                  status: 1,
                },
                detailpath: null,
                title: '新增',
                // type: 'add',
                val: 'add',
                onFinish: async (vals) => {
                  console.log(vals);
                  let params = {
                    ...vals,
                    factoryIdList: vals.factoryNames,
                    shopIdList: vals.shopId,
                    sectionIdList: vals.sectionId,
                    productionLineIdList: vals.productLineName,
                    roleIdList: vals.roleNames,
                    userCharReqList: [],
                  };
                  delete params.factoryNames;
                  delete params.shopId;
                  delete params.sectionId;
                  delete params.productLineName;
                  delete params.roleNames;
                  console.log(params, '!!!!');
                  let res = await doFetch({
                    url: urlParams.save,
                    params,
                  });
                  if (res.code === '0000') {
                    message.success('新增成功！');
                    setDrawer((s) => ({
                      ...s,
                      visible: false,
                    }));
                    actionRef.current.reload();
                  }
                },
              }));
            },
          },
        }}
      />

      <DrawerPro
        fields={columns}
        // detailpath={urlParams.detail}
        // params={{ id: drawer?.item?.id }}
        defaultFormValue={drawer?.item ?? {}}
        formRef={formRef}
        placement="right"
        onClose={() => {
          setDrawer((s) => ({
            ...s,
            visible: false,
          }));
        }}
        {...drawer}
      >
        {/* {drawer?.type == 'add' ? <Adduser /> : null} */}
      </DrawerPro>
    </div>
  );
}

export default User;
